@@ -1,5 +1,5 @@
 from sympy import *
-from util_func import *
+from difdyf.util_func import *
 import numpy as np
 
 ########### r theta phi      3-d sphere axis
